==> qucs_0.0.12.orig.tar.gz: qucs-0.0.12/qucs-core/src/tokens_dataset.h <==
/* A Bison parser, made by GNU Bison 2.3.  */

/* Skeleton interface for Bison's Yacc-like parsers in C

   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     InvalidCharacter = 258,
     Identifier = 259,
     REAL = 260,
     IMAG = 261,
     COMPLEX = 262,
     Integer = 263,
     Eol = 264,
     IndepBegin = 265,
     DepBegin = 266,
     IndepEnd = 267,
     DepEnd = 268,
     Version = 269
   };
#endif
/* Tokens.  */
#define InvalidCharacter 258
#define Identifier 259
#define REAL 260
#define IMAG 261
#define COMPLEX 262
#define Integer 263
#define Eol 264
#define IndepBegin 265
#define DepBegin 266
#define IndepEnd 267
#define DepEnd 268
#define Version 269




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
#line 65 "parse_dataset.y"
{
  char * ident;
  double f;
  struct {
    double r;
    double i;
  } c;
  long n;
  vector * v;
  dataset * data;
  strlist * list;
}
/* Line 1489 of yacc.c.  */
#line 90 "tokens_dataset.h"
	YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE dataset_lval;

==> qucs_0.0.15.orig.tar.gz: qucs-0.0.15/qucs-core/src/tokens_dataset.h <==

/* A Bison parser, made by GNU Bison 2.4.1.  */

/* Skeleton interface for Bison's Yacc-like parsers in C
   
      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
   Free Software Foundation, Inc.
   
   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.
   
   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */


/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     InvalidCharacter = 258,
     Identifier = 259,
     REAL = 260,
     IMAG = 261,
     COMPLEX = 262,
     Integer = 263,
     Eol = 264,
     IndepBegin = 265,
     DepBegin = 266,
     IndepEnd = 267,
     DepEnd = 268,
     Version = 269
   };
#endif
/* Tokens.  */
#define InvalidCharacter 258
#define Identifier 259
#define REAL 260
#define IMAG 261
#define COMPLEX 262
#define Integer 263
#define Eol 264
#define IndepBegin 265
#define DepBegin 266
#define IndepEnd 267
#define DepEnd 268
#define Version 269




#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
typedef union YYSTYPE
{

/* Line 1676 of yacc.c  */
#line 65 "parse_dataset.y"

  char * ident;
  double f;
  struct {
    double r;
    double i;
  } c;
  long n;
  vector * v;
  dataset * data;
  strlist * list;



/* Line 1676 of yacc.c  */
#line 95 "tokens_dataset.h"
} YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
#endif

extern YYSTYPE dataset_lval;
